package TestApp::TT::Filters;

use strict;
use warnings;

sub fs_hello {
    return 'hello';
}

1;

=head1 NAME

TestApp::TT::Filters -  L<Template::Filters::LazyLoader> Filters class

=head1 DESCRIPTION

Template-Toolkit Fliter modules.

=head1 SEE ALSO

L<Catalyst::TT::Filters::LazyLoader>
L<Template::Filters::LazyLoader>

=head1 AUTHOR

Tomohiro Teranishi

=cut
